@@ -36,6 +36,8 @@ describe 'manila::api' do
         )
         is_expected.to contain_manila_config('DEFAULT/default_share_type').with(:value => '<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('DEFAULT/osapi_share_workers').with(:value => '2')
+        is_expected.to contain_manila_api_paste_ini('filter:ratelimit/paste.filter_factory').with_ensure('absent')
+        is_expected.to contain_manila_api_paste_ini('filter:ratelimit/limits').with_ensure('absent')
       end
 
       it 'should run db sync' do
@@ -131,8 +133,8 @@ describe 'manila::api' do
         req_params.merge({'manage_service' => false})
       end
       it { is_expected.to contain_class('manila::policy') }
-      it 'should not change the state of the service' do
-        is_expected.to contain_service('manila-api').without_ensure
+      it 'should not configure the service' do
+        is_expected.to_not contain_service('manila-api')
       end
     end
 
@@ -142,6 +144,9 @@ describe 'manila::api' do
       end
 
       it { is_expected.to contain_class('manila::policy') }
+      it { is_expected.to contain_manila_api_paste_ini('filter:ratelimit/paste.filter_factory').with(
+        :value => 'manila.api.v1.limits:RateLimitingMiddleware.factory'
+      )}
       it { is_expected.to contain_manila_api_paste_ini('filter:ratelimit/limits').with(
         :value => '(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)'
       )}
@@ -185,15 +190,37 @@ describe 'manila::api' do
       it_raises 'a Puppet::Error', /Invalid service_name/
     end
 
-  end
+    context 'enabled_share_protocols is set' do
+      let :params do
+        req_params.merge!({
+          :enabled_share_protocols => 'NFS'
+        })
+      end
 
+      it 'configures enabled_share_protocols' do
+        is_expected.to contain_manila_config('DEFAULT/enabled_share_protocols').with_value('NFS')
+      end
+    end
+
+    context 'enabled_share_protocols is set by array' do
+      let :params do
+        req_params.merge!({
+          :enabled_share_protocols => ['NFS', 'CIFS']
+        })
+      end
+
+      it 'configures enabled_share_protocols' do
+        is_expected.to contain_manila_config('DEFAULT/enabled_share_protocols').with_value('NFS,CIFS')
+      end
+    end
+  end
 
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({ :fqdn => 'some.host.tld'}))
+        facts.merge!(OSDefaults.get_facts())
       end
       it_behaves_like 'manila::api'
     end
