@@ -25,7 +25,7 @@ describe 'manila::client' do
       end
 
       let :platform_params do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package => 'python3-manilaclient' }
         when 'RedHat'
