@@ -33,11 +33,15 @@ describe 'manila' do
           :topics        => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__rabbit('manila_config').with(
-          :rabbit_use_ssl          => '<SERVICE DEFAULT>',
-          :amqp_durable_queues     => '<SERVICE DEFAULT>',
-          :rabbit_ha_queues        => '<SERVICE DEFAULT>',
-          :kombu_failover_strategy => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread    => '<SERVICE DEFAULT>',
+          :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+          :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues                => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_manila_config('DEFAULT/storage_availability_zone').with(
           :value => 'nova'
@@ -210,12 +214,12 @@ describe 'manila' do
       end
 
       it { is_expected.to contain_oslo__messaging__amqp('manila_config').with(
-          :server_request_prefix => 'exclusive',
-          :broadcast_prefix      => 'broadcast',
-          :group_request_prefix  => 'unicast',
-          :container_name        => 'guest',
-          :idle_timeout          => '0',
-          :trace                 => 'false',
+          :server_request_prefix => '<SERVICE DEFAULT>',
+          :broadcast_prefix      => '<SERVICE DEFAULT>',
+          :group_request_prefix  => '<SERVICE DEFAULT>',
+          :container_name        => '<SERVICE DEFAULT>',
+          :idle_timeout          => '<SERVICE DEFAULT>',
+          :trace                 => '<SERVICE DEFAULT>',
           :ssl_ca_file           => '<SERVICE DEFAULT>',
           :ssl_cert_file         => '<SERVICE DEFAULT>',
           :ssl_key_file          => '<SERVICE DEFAULT>',
