@@ -73,7 +73,7 @@ describe 'manila::backend::cephfs' do
       }).each do |os,facts|
         context "on #{os}" do
           let (:facts) do
-            facts.merge(OSDefaults.get_facts({ :osfamily => "#{os}" }))
+            facts.merge(OSDefaults.get_facts())
           end
 
           it_configures 'cephfs driver'
