@@ -47,7 +47,7 @@ describe 'manila::backend::glusternative' do
       end
 
       let :platform_params do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           {
             :gluster_client_package_name => 'glusterfs-client',
